handler

Attribute Macro handler 

#[handler]
Converts a synchronous or asynchronous function returning Result into a const_router handler.

The function may take either no request argument or one request argument:

  • fn() -> Result<TResponse, TError>
  • fn(TRequest) -> Result<TResponse, TError>
  • async fn() -> Result<TResponse, TError>
  • async fn(TRequest) -> Result<TResponse, TError>